@@ -14,7 +14,7 @@ if sys.platform == "win32":
     USERNAME = os.environ.get("USERNAME", None)
     FINTIX_HOME_DIR = os.path.join(os.environ.get("USERPROFILE", os.path.join("C:\\Users\\", USERNAME)), ".fintix")
     FINTIX_IO_DATA_DIR = os.path.join(FINTIX_HOME_DIR, "data")
-    FINTIX_IO_LOG_DIR = os.path.join(FINTIX_HOME_DIR, "log")
+    FINTIX_IO_LOG_DIR = os.path.join(FINTIX_HOME_DIR, "logs", "modelcurator")
 else:
     FINTIX_IO_DATA_DIR = "/var/lib/fintix"
     FINTIX_IO_LOG_DIR = "/var/log/fintix"
