@@ -11,4 +11,7 @@ INVALID_INPUT_TYPE = 6
 MODEL_CODE_IMPORT_ERR = 7
 CONFIG_NOT_INITIALIZED = 8
 INVALID_CONFIG_PATH = 9
-MODEL_DOWNLOADING_ERROR = 10
\ No newline at end of file
+MODEL_DOWNLOADING_ERROR = 10
+INVALID_PHASE = 11
+CALLBACK_IS_NOT_CALLABLE = 12
+INPUT_TOPIC_NOT_DEFINED = 13
\ No newline at end of file
