@@ -29,6 +29,7 @@ def start():
     setting = Settings.getInstance().get_settings()
     model_name = setting.get('model')
     phase = setting.get('phase')
+    data_source = setting.get('data_source')
     input_topic = setting.get('input_topic')
     trigger_type = setting.get('trigger').get('type')
     trigger_interval = setting.get('trigger').get('interval')
@@ -76,6 +77,7 @@ def start():
                         model=model,
                         model_name=model_name,
                         phase=phase,
+                        data_source=data_source,
                         input_topic=input_topic,
                         trigger_type=trigger_type,
                         trigger_interval=trigger_interval,
